@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Mouse;
 use Path::Class;
@@ -43,6 +43,17 @@ has env => (
     default => sub {{}},
 );
 
+has verbose => (
+    is => 'rw',
+    isa => 'Bool',
+    default => 1,
+);
+
+has has_user_field => (
+    is => 'rw',
+    isa => 'Bool',
+    default => undef,
+);
 
 no Mouse;
 
@@ -52,7 +63,7 @@ sub BUILD {
     my $line_number = 1;
     for my $line (split /\r?\n/, $self->content) {
         my $entry_class = 'Parse::Crontab::Entry::'. $self->_decide_entry_class($line);
-        my $entry = $entry_class->new(line => $line, line_number => $line_number);
+        my $entry = $entry_class->new(line => $line, line_number => $line_number, has_user_field => $self->has_user_field);
         $line_number++;
 
         if ($entry_class eq 'Parse::Crontab::Entry::Env' && !$entry->is_error) {
@@ -61,6 +72,13 @@ sub BUILD {
         }
         push @{$self->entries}, $entry;
     }
+
+    if ($self->verbose) {
+        my $error = $self->error_messages;
+        warn $error if $error;
+        my $warn  = $self->warning_messages;
+        warn $warn  if $warn;
+    }
 }
 
 sub is_valid {
@@ -81,6 +99,15 @@ sub error_messages {
     join "\n", @errors;
 }
 
+sub warning_messages {
+    my $self = shift;
+    my @errors;
+    for my $entry ($self->entries) {
+        push @errors, $entry->warning_message if $entry->has_warnings;
+    }
+    join "\n", @errors;
+}
+
 sub jobs {
     my $self = shift;
     grep {$_->isa('Parse::Crontab::Entry::Job')} $self->entries;
@@ -139,6 +166,21 @@ This software is for parsing and validating Vixie crontab files.
 
 =head1 INTERFACE
 
+=head2 Constructor Options
+
+=head3 C<< file >>
+
+crontab file.
+
+=head3 C<< verbose >>
+
+verbose option (Default: 1).
+If errors/warnings exist, errors/warnings message is dumped immediately when parsing.
+
+=head3 C<< has_user_field >>
+
+for the crontab format having user field (system-width cron files and all that).
+
 =head2 Functions
 
 =head3 C<< is_valid() >>
